# Examples
We offer some example scripts to showcase the functionalities of the ROSCO toolbox. This offers a non-inclusive overview of some of the primary functionalities of the ROSCO toolbox. Enjoy!

Examples: 
1. Load and save a turbine model. Prints some basic turbine data, and saves the turbine.
2. Load a turbine model from saved pickle, make a Cp surface plot.
3. Run CCblade, save a rotor performance text file.
4. Load a turbine model and tune the controller.
5. Run and plot a simple simple step wind simulation.
6. Load a turbine, tune a controller, run an OpenFAST simulation.
7. Load saved turbine, tune controller, plot minimum pitch schedule.
8. Plot some OpenFAST output data.
9. Run turbsim to compile binary.
10. Tune a controller for distributed aerodynamic control.
11. Generate simplified linear models, save the parameters to a file.
12. Run robust controller tuning
13. Tune and run a controller with IPC
14. Tune a controller with OpenLoop control commands inputs